@@ -1,10 +1,6 @@
-#!/usr/bin/perl
-
 package MyCPAN::App::Indexer::DPAN;
 use strict;
-
 use warnings;
-no warnings;
 
 use subs qw(get_caller_info);
 use vars qw($VERSION $indexer_logger $reporter_logger);
@@ -14,16 +10,17 @@ use vars qw($VERSION $indexer_logger $reporter_logger);
 # it's a problem with who's cleanup() get called
 use base qw(MyCPAN::App::BackPAN::Indexer MyCPAN::Indexer MyCPAN::Indexer::Reporter::AsYAML);
 
-use File::Basename;
+use Cwd qw(cwd);
+use File::Basename qw(dirname);
+use File::Path qw(mkpath);
+use File::Temp qw(tempdir);
 use File::Spec::Functions qw(catfile);
-use File::Path;
-use YAML;
 
-$VERSION = '1.18_04';
+$VERSION = '1.21';
 
 =head1 NAME
 
-MyCPAN::Indexer::DPAN - Create a D(ark)PAN out of the indexed distributions
+MyCPAN::App::Indexer::DPAN - Create a D(ark)PAN out of the indexed distributions
 
 =head1 SYNOPSIS
 
@@ -33,8 +30,8 @@ MyCPAN::Indexer::DPAN - Create a D(ark)PAN out of the indexed distributions
 
 This module implements the indexer_class and reporter_class components
 to allow C<backpan_indexer.pl> to create a CPAN-like directory structure
-with its associated index files. This application of MyCPAN::Indexer is 
-specifically aimed at creating a 02packages.details file, so it 
+with its associated index files. This application of MyCPAN::Indexer is
+specifically aimed at creating a 02packages.details file, so it
 strives to collect a minimum of information.
 
 It runs through the indexing and prints a report at the end of the run.
@@ -52,7 +49,8 @@ BEGIN {
 	}
 
 # Override the exit from the parent class so we can embed a run
-# inside a bigger application
+# inside a bigger application. Applications should override this
+# on their own to do any final processing they want.
 sub _exit { 1 }
 
 __PACKAGE__->activate( @ARGV ) unless caller;
@@ -76,9 +74,12 @@ sub examine_dist_steps
 	{
 	my @methods = (
 		#    method                error message                  fatal
-		[ 'unpack_dist',        "Could not unpack distribtion!",     1 ],
+		[ 'unpack_dist',        "Could not unpack distribution!",    1 ],
 		[ 'find_dist_dir',      "Did not find distro directory!",    1 ],
 		[ 'find_modules',       "Could not find modules!",           1 ],
+		[ 'examine_modules',    "Could not process modules!",        0 ],
+		[ 'find_tests',         "Could not find tests!",             0 ],
+		[ 'examine_tests',      "Could not process tests!",          0 ],
 		);
 	}
 
@@ -115,7 +116,7 @@ sub get_module_info_tasks
 	[ 'extract_module_version',       'Extract the version of the module'     ],
 	)
 	}
-	
+
 =item setup_run_info
 
 Like C<setup_run_info> in C<MyCPAN::Indexer>, but it remembers fewer
@@ -204,6 +205,8 @@ sub final_words
 	require CPAN::PackageDetails;
 	my $package_details = CPAN::PackageDetails->new;
 
+	$reporter_logger->info( "Creating index files" );
+
 	require version;
 	foreach my $file ( readdir( $dh ) )
 		{
@@ -215,32 +218,32 @@ sub final_words
 			};
 
 		my $dist_file = $yaml->{dist_info}{dist_file};
-		
+
 		#print STDERR "Dist file is $dist_file\n";
-		
+
 		# some files may be left over from earlier runs, even though the
 		# original distribution has disappeared. Only index distributions
 		# that are still there
 		#my @backpan_dirs = @{ $Notes->{config}->backpan_dir };
 		# check that dist file is in one of these directories
 		next unless -e $dist_file; # && $dist_file =~ m/^\Q$backpan_dir/;
-		
+
 		my $dist_dir = dirname( $dist_file );
-		
+
 		$dirs_needing_checksums{ $dist_dir }++;
 
-=pod 
+=pod
 
 This is the big problem. Since we didn't really parse the source code, we
 don't really know how to match up packages and VERSIONs. The best we can
-do right now is assume that a $VERSION we found goes with the packages 
+do right now is assume that a $VERSION we found goes with the packages
 we found.
 
-Additionally, that package variable my have been in one package, but 
+Additionally, that package variable my have been in one package, but
 been the version for another package. For example:
 
 	package DBI;
-	
+
 	$DBI::PurePerl::VERSION = 1.23;
 
 =cut
@@ -251,10 +254,10 @@ been the version for another package. For example:
 			my $version  = $module->{version_info}{value};
 			$version = $version->numify if eval { $version->can('numify') };
 
-			( my $version_variable = $module->{version_info}{identifier} )
+			( my $version_variable = $module->{version_info}{identifier} || '' )
 				=~ s/(?:\:\:)?VERSION$//;
 			$reporter_logger->debug( "Package from version variable is $version_variable" );
-			
+
 			PACKAGE: foreach my $package ( @$packages )
 				{
 				if( $version_variable && $version_variable ne $package )
@@ -262,19 +265,19 @@ been the version for another package. For example:
 					$reporter_logger->debug( "Skipping package [$package] since version variable [$version_variable] is in a different package" );
 					next;
 					}
-					
+
 				# broken crap that works on Unix and Windows to make cpanp
 				# happy.
 				( my $path = $dist_file ) =~ s/.*authors.id.//g;
-				
+
 				$path =~ s|\\+|/|g; # no windows paths.
-				
+
 				if( $class->skip_package( $package ) )
 					{
 					$reporter_logger->debug( "Skipping $package: excluded by config" );
 					next PACKAGE;
 					}
-					
+
 				$package_details->add_entry(
 					'package name' => $package,
 					version        => $version,
@@ -309,31 +312,31 @@ been the version for another package. For example:
 =item guess_package_name
 
 Given information about the module, make a guess about which package
-is the primary one. This is 
+is the primary one. This is
 
 =cut
 
 sub guess_package_name
 	{
 	my( $self, $module_info ) = @_;
-	
-	
+
+
 	}
 
 =item get_package_version( MODULE_INFO, PACKAGE )
 
-Get the $VERSION associated with PACKAGE. You probably want to use 
-C<guess_package_name> first to figure out which package is the 
+Get the $VERSION associated with PACKAGE. You probably want to use
+C<guess_package_name> first to figure out which package is the
 primary one that you should index.
 
 =cut
 
 sub get_package_version
 	{
-	
-	
+
+
 	}
-	
+
 =item skip_package( PACKAGE )
 
 Returns true if the indexer should ignore PACKAGE.
@@ -345,21 +348,16 @@ By default, this skips the Perl special packages:
 	MM
 	DB
 	bytes
-	
+
 There isn't a way to configure additional packages yet.
 
 =cut
 
-BEGIN {
-my %skips = map { $_, 1 } qw(main bytes MY MM DB DynaLoader);
-
 sub skip_package
 	{
-	my( $class, $package ) = @_;
-	
-	exists $skips{ $package };
+
+
 	}
-}
 
 =item create_package_details
 
@@ -369,13 +367,13 @@ here.
 =cut
 
 sub create_package_details
-	{
-	my( $self, $index_dir ) = @_;
-	
-		
-	1;
-	}
-	
+      {
+      my( $self, $index_dir ) = @_;
+
+
+      1;
+      }
+
 =item create_modlist
 
 If a modules/03modlist.data.gz does not already exist, this creates a
@@ -388,16 +386,16 @@ reference.
 sub create_modlist
 	{
 	my( $self, $index_dir ) = @_;
-	
+
 	my $module_list_file = catfile( $index_dir, '03modlist.data.gz' );
 	$reporter_logger->debug( "modules list file is [$module_list_file]");
 
 	if( -e $module_list_file )
 		{
-		$reporter_logger->debug( "File [$module_list_file] already exists" );
+		$reporter_logger->debug( "File [$module_list_file] already exists!" );
 		return 1;
 		}
-		
+
 	my $fh = IO::Compress::Gzip->new( $module_list_file );
 	print $fh <<"HERE";
 File:        03modlist.data
@@ -415,7 +413,7 @@ HERE
 
 	close $fh;
 	}
-	
+
 =item create_checksums
 
 Creates the CHECKSUMS file that goes in each author directory in CPAN.
@@ -427,21 +425,21 @@ updating an entire tree. We just do a little logging.
 sub create_checksums
 	{
 	my( $self, $dirs ) = @_;
-	
+
 	require CPAN::Checksums;
 	foreach my $dir ( @$dirs )
 		{
-        my $rc = eval{ CPAN::Checksums::updatedir( $dir ) };
-		$reporter_logger->error( "Couldn't create CHECKSUMS for $dir: $@") unless $rc;
-		$reporter_logger->info(
-			do {
-				if(    $rc == 1 ) { "Valid CHECKSUMS file is already present in $dir: skipping" }
-				elsif( $rc == 2 ) { "Wrote new CHECKSUMS file in $dir" }
-				else              { "updatedir unexpectedly returned true [$rc] for $dir" }
-			} );
-		}	
+		my $rc = eval{ CPAN::Checksums::updatedir( $dir ) };
+			$reporter_logger->error( "Couldn't create CHECKSUMS for $dir: $@" ) if $@;
+			$reporter_logger->info(
+				do {
+					  if(    $rc == 1 ) { "Valid CHECKSUMS file is already present" }
+					  elsif( $rc == 2 ) { "Wrote new CHECKSUMS file in $dir" }
+					  else              { "updatedir unexpectedly returned an error" }
+				} );
+		}
 	}
-	
+
 =back
 
 =head1 TO DO
@@ -458,7 +456,8 @@ sub create_checksums
 
 This code is in Github:
 
-	git://github.com/briandfoy/mycpan-indexer.git
+      git://github.com/briandfoy/mycpan-indexer.git
+      git://github.com/briandfoy/mycpan-app-dpan.git
 
 =head1 AUTHOR
 
@@ -471,5 +470,3 @@ Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
 You may redistribute this under the same terms as Perl itself.
 
 =cut
-
-1;
